@@ -1,11 +1,3 @@
-#' Flexible Regularized Estimating Equations
-#'
-#' Unified regularized estimating equation solver. Currently include one solver with the l1 penalty only. More solvers and penalties are under development.
-#' 
-#' @docType package
-#' @name free-package
-NULL
-
 #' Main solver of \code{free}
 #' 
 #' @param p The dimension of the dataset
